package com.lantone.qc.kernel.structure.ai;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.lantone.qc.kernel.client.CRFServiceClient;
import com.lantone.qc.kernel.structure.ai.process.EntityProcessThreeLevelWard;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.model.label.ThreeLevelWardLabel;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : ThreeLevelWardAI
 * @Description :
 * @Author : 胡敬
 * @Date: 2020-03-23 09:52
 */
public class ThreeLevelWardAI extends ModelAI {
    /**
     *
     */
    public static List<String> medicalTextType = Arrays.asList("CourseRecord_cx");
    public static String entityRelationObject = "entity_relation_object";
    public static String outputs = "outputs";
    public static String content = "content";

    public void medrec(InputInfo inputInfo, CRFServiceClient crfServiceClient) {
        JSONArray crfContent = new JSONArray();
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        //主治/主任首次查房记录
        Map<String, Map<String, String>> firstWardRecord = CatalogueUtil.extractWardRecord(threeLevelWardDocs);
        //主治医师首次查房记录
        if (firstWardRecord.get(Content.indications) != null) {
            putContent(crfContent, medicalTextType.get(0), firstWardRecord.get(Content.indications).get("病情记录"), Content.indications);
        }
        //主任医师首次查房记录
        if (firstWardRecord.get(Content.director) != null) {
            putContent(crfContent, medicalTextType.get(0), firstWardRecord.get(Content.director).get("病情记录"), Content.director);
        }

        JSONObject midData = loadAI(crfContent, crfServiceClient);//crf返回数据

        //主治医师首次查房记录模型输出
        if (midData.get(Content.indications) != null) {
            putWardRoundCrfData(midData.getJSONObject(Content.indications), inputInfo, Content.indications);//查房记录
        }
        //主任医师首次查房记录模型输出
        if (midData.get(Content.director) != null) {
            putWardRoundCrfData(midData.getJSONObject(Content.director), inputInfo, Content.indications);//查房记录
        }
    }

    /**
     * 处理查房记录
     *
     * @param jsonObject
     * @param inputInfo
     */
    public void putWardRoundCrfData(JSONObject jsonObject, InputInfo inputInfo, String detailTitle) {
        JSONObject aiOut = loadEntity(jsonObject, entityRelationObject, outputs, content);
        //使用现病史结构来处理病历特点
        EntityProcessThreeLevelWard entityProcessThreeLevelWard = new EntityProcessThreeLevelWard();
        ThreeLevelWardLabel threeLevelWardLabel = entityProcessThreeLevelWard.extractEntity(aiOut);
        threeLevelWardLabel.setTitle(detailTitle);
        ThreeLevelWardDoc threeLevelWardDoc = new ThreeLevelWardDoc();
        threeLevelWardDoc.setThreeLevelWardLabel(threeLevelWardLabel);
        //临床表现
        inputInfo.getThreeLevelWardDocs().add(threeLevelWardDoc);
    }
}